@@ -1,7 +1,7 @@
 from abc import ABC
 from typing import TypeVar
 
-from settings import IScenarioSettings
+from wwtp.api.settings import IScenarioSettings
 
 SS = TypeVar('SS', bound=IScenarioSettings)
 
